@@ -62,9 +62,9 @@ MoonPAWidget::MoonPAWidget(const TQString& configFile, Type type, int actions,
     popup = new TQPopupMenu();
     popup->insertItem(SmallIcon("kmoon"),
 		      i18n("&About"), this,
-		      TQT_SLOT(showAbout()));
+		      TQ_SLOT(showAbout()));
     popup->insertItem(SmallIcon("configure"), i18n("&Configure..."), this,
-		      TQT_SLOT(settings()));
+		      TQ_SLOT(settings()));
 
     // missuse timerEvent for initialising
     timerEvent(0);
@@ -134,11 +134,11 @@ void MoonPAWidget::mousePressEvent( TQMouseEvent *e)
     if (!popup)
       return;
 
-    if (e->button() == Qt::RightButton) {
+    if (e->button() == TQt::RightButton) {
       popup->popup(mapToGlobal(e->pos()));
       popup->exec();
     }
-    if (e->button() == Qt::LeftButton) {
+    if (e->button() == TQt::LeftButton) {
       showAbout();
     }
 }
